use crate::ems::bms::bms::Bms;
use crate::ems::pcs::pcs::Pcs;
use tokio::task::JoinHandle;

pub trait Service {
    fn run(&self) -> Result<JoinHandle<()>, anyhow::Error>;
}

/// EMS
/// devices: 实现了Service trait的列表
pub struct Ems {
    devices: Vec<Box<dyn Service>>,
}
impl Ems {
    pub fn new() -> Self {
        let pcs = Pcs::new();
        let bms = Bms::new();
        let mut devices: Vec<Box<dyn Service>> = Vec::new();
        devices.push(Box::new(pcs));
        devices.push(Box::new(bms));
        Ems { devices }
    }

    pub async fn start_services(&self) -> Result<(), anyhow::Error> {
        let mut handles = Vec::new();
        for dev in &self.devices {
            let handle = dev.run()?;
            handles.push(handle);
        }
        for handle in handles {
            handle.await?;
        }
        Ok(())
    }
}
